@@ -3,6 +3,7 @@ from __future__ import annotations
 import argparse
 import contextlib
 import html
+import importlib.metadata
 import json
 import os.path
 import shutil
@@ -13,7 +14,6 @@ from typing import Callable
 from typing import Generator
 from typing import Sequence
 
-import pkg_resources
 from markdown_code_blocks import CodeRenderer
 from markdown_code_blocks import highlight
 
@@ -51,7 +51,7 @@ index.htm: {MTPVERSION} slides.md
 \t{sys.executable} -m markdown_to_presentation run-backend $@
 '''  # noqa: E501
 
-VERSION = pkg_resources.get_distribution('markdown-to-presentation').version
+VERSION = importlib.metadata.version('markdown-to-presentation')
 
 
 @contextlib.contextmanager
@@ -66,7 +66,8 @@ def cwd(pth: str) -> Generator[None, None, None]:
 
 def _read_mtp_version() -> str | None:
     try:
-        return open(MTPVERSION).read()
+        with open(MTPVERSION) as f:
+            return f.read()
     except OSError:
         return None
 
@@ -368,7 +369,8 @@ def _to_slide(md: str) -> str:
 
 
 def _make_index_htm(target: str) -> int:
-    contents = open('slides.md').read()
+    with open('slides.md') as f:
+        contents = f.read()
     html = INDEX_TMPL.format(
         slides=''.join(
             _to_slide(slide) for slide in contents.split(SLIDE_DELIM)
